@@ -25,9 +25,10 @@ along with Felupe.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-import pytest
-import felupe as fe
 import numpy as np
+import pytest
+
+import felupe as fe
 
 
 def pre(values=0):
@@ -72,6 +73,8 @@ def pre_mixed():
     assert np.all(f.values()[0][0] == 1)
     assert len(g.fields) == 3
 
+    fe.Field(r, dim=9, values=np.eye(3))
+
     return r, f, u, p, J
 
 
@@ -107,6 +110,22 @@ def test_axi():
     u.extract(grad=True, add_identity=False)
 
 
+def test_mixed_lagrange():
+
+    order = 4
+
+    m = fe.Cube(n=order + 1)
+    md = fe.Cube(n=order)
+
+    m.update(np.arange(m.npoints).reshape(1, -1), cell_type="VTK_LAGRANGE_HEXAHEDRON")
+    md.update(np.arange(md.npoints).reshape(1, -1), cell_type="VTK_LAGRANGE_HEXAHEDRON")
+
+    r = fe.RegionLagrange(m, order=order, dim=3)
+    g = fe.FieldsMixed(r, mesh=md)
+
+    assert len(g.fields) == 3
+
+
 def test_3d():
 
     r, u = pre()
@@ -197,3 +216,4 @@ if __name__ == "__main__":
     test_axi()
     test_3d()
     test_3d_mixed()
+    test_mixed_lagrange()
