@@ -24,13 +24,13 @@ You should have received a copy of the GNU General Public License
 along with Felupe.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-import pytest
 import numpy as np
+import pytest
+
 import felupe as fe
 
 
 def test_meshes():
-
     m = fe.Mesh(
         points=np.array(
             [
@@ -43,6 +43,11 @@ def test_meshes():
         cell_type="triangle",
     )
 
+    n = m.copy()
+    n.update(m.cells, cell_type="my-fancy-cell-type")
+
+    assert n.cell_type == "my-fancy-cell-type"
+
     fe.mesh.convert(m, order=0)
     fe.mesh.convert(m, order=0, calc_points=True)
     fe.mesh.convert(m, order=2)
@@ -138,6 +143,11 @@ def test_meshes():
     assert m_dg.dim == m.dim
     assert m_dg.npoints == m.cells.size
 
+    m_dg = m.disconnect(points_per_cell=2, calc_points=False)
+    assert np.allclose(m_dg.points, 0)
+    assert m_dg.npoints == m.ncells * 2
+    assert m_dg.cell_type is None
+
     fe.mesh.sweep(m)
     fe.mesh.sweep(m.points, m.cells, m.cell_type, decimals=4)
 
@@ -150,7 +160,6 @@ def test_meshes():
 
 
 def test_mirror():
-
     for kwargs in [
         dict(axis=None, normal=[1, 0, 0]),
         dict(axis=None, normal=[1, 1, 0]),
@@ -161,11 +170,9 @@ def test_mirror():
         dict(axis=1, normal=[]),
         dict(axis=2, normal=[]),
     ]:
-
         axis = kwargs["axis"]
 
         if axis is None or axis < 1:
-
             m = fe.mesh.Line()
             r = fe.Region(m, fe.Line(), fe.GaussLegendre(1, 1))
             n = fe.mesh.mirror(m, **kwargs)
@@ -173,7 +180,6 @@ def test_mirror():
             assert np.isclose(r.dV.sum(), s.dV.sum())
 
         if axis is None or axis < 2:
-
             m = fe.Rectangle()
             r = fe.RegionQuad(m)
             n = fe.mesh.mirror(m, **kwargs)
@@ -214,7 +220,6 @@ def test_mirror():
 
 
 def test_triangulate():
-
     m = fe.Rectangle(n=3)
     n = fe.mesh.triangulate(m)
 
@@ -237,7 +242,6 @@ def test_triangulate():
 
 
 def test_runouts():
-
     m = fe.Rectangle(n=3)
 
     n = fe.mesh.runouts(m, values=[0.0], axis=0, centerpoint=[0, 0])
@@ -257,7 +261,6 @@ def test_runouts():
 
 
 def test_concatenate():
-
     m = fe.Rectangle(n=3)
 
     n = fe.mesh.concatenate([m, m, m])
@@ -267,7 +270,6 @@ def test_concatenate():
 
 
 def test_grid():
-
     m = fe.Rectangle(b=(10, 3), n=(4, 5))
 
     x = np.linspace(0, 10, 4)
@@ -279,7 +281,6 @@ def test_grid():
 
 
 def test_grid_1d():
-
     m = fe.mesh.Line(b=10, n=6)
 
     x = np.linspace(0, 10, 6)
@@ -290,7 +291,6 @@ def test_grid_1d():
 
 
 def test_container():
-
     mesh_1 = fe.Rectangle()
     mesh_2 = fe.Rectangle(a=(1, 0), b=(2, 1))
     mesh_3 = fe.mesh.triangulate(fe.Rectangle(a=(2, 0), b=(3, 1)))
@@ -324,7 +324,6 @@ def test_container():
 
 
 def test_read(filename="tests/mesh.bdf"):
-
     mesh = fe.mesh.read(filename=filename, dim=2)[0]
     assert mesh.dim == 2
 
